@@ -39,18 +39,21 @@ test_that("attempt run with incomplete attributes", {
   expect_error(sim_manager$run(), "The model simulator has not been set")
   sim_manager$model_simulator <- ModelSimulator$new()
   sim_manager$model_simulator$simulation_function <- NULL
-  expect_error(sim_manager$run(), "The model simulator function has not been set")
+  expect_error(sim_manager$run(),
+               "The model simulator function has not been set")
   sim_manager$model_simulator$simulation_function <- "max"
   # No results output directory
   expect_error(sim_manager$run(), "No output directory set for results")
   sim_manager$results_dir <- "invalid_dir"
-  expect_error(sim_manager$run(), "Could not find results directory invalid_dir")
+  expect_error(sim_manager$run(),
+               "Could not find results directory invalid_dir")
   sim_manager$results_dir <- TEST_DIRECTORY
   # With incomplete model
   expect_null(sim_manager$nested_model)
   generator <- Generator$new(
     generative_requirements = list(attr3 = "function"),
-    inputs = c("attr2"), outputs = c("attr3")
+    inputs = c("attr2"),
+    outputs = c("attr3")
   )
   generator$function_templates <- list(attr3 = list(
     function_def = function(params) {
@@ -59,19 +62,29 @@ test_that("attempt run with incomplete attributes", {
     call_params = c("attr2")
   ))
   sim_manager$generators <- list(gen3 = generator)
-  expect_error(sim_manager$run(), "Model attributes are incomplete: time_steps")
+  expect_error(sim_manager$run(),
+               "Model attributes are incomplete: time_steps")
   expect_is(sim_manager$nested_model, "SimulationModel")
-  expect_equal(sim_manager$nested_model$attached, list(
-    sample_model_names = c("attr1", "attr2"),
-    sample_generative_names = list("attr3")
-  ))
+  expect_equal(
+    sim_manager$nested_model$attached,
+    list(
+      sample_model_names = c("attr1", "attr2"),
+      sample_generative_names = list("attr3")
+    )
+  )
   # Set model sample
   model_clone <- sim_manager$nested_model$clone()
   sim_manager$set_model_sample(model_clone, 1)
-  expect_equal(model_clone$get_attributes(), list(
-    attr1 = 3, attr2 = 5, sample_model_names = c("attr1", "attr2"),
-    sample_generative_names = list("attr3"), attr3 = 7
-  ))
+  expect_equal(
+    model_clone$get_attributes(),
+    list(
+      attr1 = 3,
+      attr2 = 5,
+      sample_model_names = c("attr1", "attr2"),
+      sample_generative_names = list("attr3"),
+      attr3 = 7
+    )
+  )
 })
 
 test_that("run with complete attributes", {
@@ -84,10 +97,12 @@ test_that("run with complete attributes", {
     parallel_cores = 2,
     results_dir = tempdir()
   )
-  sim_manager$model_simulator$simulation_function <- function(model) model$get_attributes(c("attr1", "attr2", "attr3"))
+  sim_manager$model_simulator$simulation_function <- function(model)
+    model$get_attributes(c("attr1", "attr2", "attr3"))
   generator <- Generator$new(
     generative_requirements = list(attr3 = "function"),
-    inputs = c("attr2"), outputs = c("attr3")
+    inputs = c("attr2"),
+    outputs = c("attr3")
   )
   generator$function_templates <- list(attr3 = list(
     function_def = function(params) {
@@ -97,23 +112,37 @@ test_that("run with complete attributes", {
   ))
   sim_manager$generators <- list(gen3 = generator)
   run_output <- sim_manager$run()
-  expect_named(run_output, c("summary", "failed_indices", "warning_indices", "full_log"))
-  expect_equal(run_output$summary, "2 of 2 sample models ran and saved results successfully")
+  expect_named(run_output,
+               c("summary", "failed_indices", "warning_indices", "full_log"))
+  expect_equal(run_output$summary,
+               "2 of 2 sample models ran and saved results successfully")
   expect_length(run_output$failed_indices, 0)
   expect_length(run_output$warning_indices, 0)
   expect_equal(run_output$full_log, list(
-    list(
-      successful = TRUE,
-      message = "Model sample 1 simulation ran successfully and the results were saved"
-    ),
-    list(
-      successful = TRUE,
-      message = "Model sample 2 simulation ran successfully and the results were saved"
-    )
+    list(successful = TRUE, message = "Model sample 1 simulation ran successfully and the results were saved"),
+    list(successful = TRUE, message = "Model sample 2 simulation ran successfully and the results were saved")
+  ))
+  expect_true(all(
+    c(
+      "sample_1_results.RData",
+      "sample_2_results.RData",
+      "simulation_log.txt"
+    ) %in% list.files(sim_manager$results_dir)
+  ))
+  expect_equal(readRDS(
+    file.path(sim_manager$results_dir, "sample_1_results.RData")
+  ), list(
+    attr1 = 3,
+    attr2 = 5,
+    attr3 = 7
+  ))
+  expect_equal(readRDS(
+    file.path(sim_manager$results_dir, "sample_2_results.RData")
+  ), list(
+    attr1 = 4,
+    attr2 = 6,
+    attr3 = 8
   ))
-  expect_true(all(c("sample_1_results.RData", "sample_2_results.RData", "simulation_log.txt") %in% list.files(sim_manager$results_dir)))
-  expect_equal(readRDS(file.path(sim_manager$results_dir, "sample_1_results.RData")), list(attr1 = 3, attr2 = 5, attr3 = 7))
-  expect_equal(readRDS(file.path(sim_manager$results_dir, "sample_2_results.RData")), list(attr1 = 4, attr2 = 6, attr3 = 8))
 })
 
 test_that("run with warnings", {
@@ -133,7 +162,8 @@ test_that("run with warnings", {
   }
   generator <- Generator$new(
     generative_requirements = list(attr3 = "function"),
-    inputs = c("attr2"), outputs = c("attr3")
+    inputs = c("attr2"),
+    outputs = c("attr3")
   )
   generator$function_templates <- list(attr3 = list(
     function_def = function(params) {
@@ -143,8 +173,12 @@ test_that("run with warnings", {
   ))
   sim_manager$generators <- list(gen3 = generator)
   run_output <- sim_manager$run()
-  expect_named(run_output, c("summary", "failed_indices", "warning_indices", "full_log"))
-  expect_equal(run_output$summary, "2 of 2 sample models ran and saved results successfully with warnings")
+  expect_named(run_output,
+               c("summary", "failed_indices", "warning_indices", "full_log"))
+  expect_equal(
+    run_output$summary,
+    "2 of 2 sample models ran and saved results successfully with warnings"
+  )
   expect_length(run_output$failed_indices, 0)
   expect_length(run_output$warning_indices, 2)
   expect_equal(run_output$full_log, list(
@@ -159,9 +193,27 @@ test_that("run with warnings", {
       warnings = "Warning in self$simulation_function(self$simulation_model): Test warning"
     )
   ))
-  expect_true(all(c("sample_1_results.RData", "sample_2_results.RData", "simulation_log.txt") %in% list.files(sim_manager$results_dir)))
-  expect_equal(readRDS(file.path(sim_manager$results_dir, "sample_1_results.RData")), list(attr1 = 3, attr2 = 5, attr3 = 7))
-  expect_equal(readRDS(file.path(sim_manager$results_dir, "sample_2_results.RData")), list(attr1 = 4, attr2 = 6, attr3 = 8))
+  expect_true(all(
+    c(
+      "sample_1_results.RData",
+      "sample_2_results.RData",
+      "simulation_log.txt"
+    ) %in% list.files(sim_manager$results_dir)
+  ))
+  expect_equal(readRDS(
+    file.path(sim_manager$results_dir, "sample_1_results.RData")
+  ), list(
+    attr1 = 3,
+    attr2 = 5,
+    attr3 = 7
+  ))
+  expect_equal(readRDS(
+    file.path(sim_manager$results_dir, "sample_2_results.RData")
+  ), list(
+    attr1 = 4,
+    attr2 = 6,
+    attr3 = 8
+  ))
 })
 
 test_that("getters and setters handle errors", {
@@ -170,3 +222,33 @@ test_that("getters and setters handle errors", {
   expect_error(sim_manager$nested_model(c(1, 2, 3)))
   expect_error(sim_manager$model_simulator(c(TRUE, FALSE)))
 })
+
+test_that("initialization with explicit model_simulator", {
+  custom_simulator <- ModelSimulator$new(simulation_function = "max")
+  sim_manager <- SimulationManager$new(model_simulator = custom_simulator)
+  expect_identical(sim_manager$model_simulator, custom_simulator)
+})
+
+test_that("generator input errors", {
+  sim_manager <- SimulationManager$new(
+    model_template = SimulationModel$new(),
+    sample_data = data.frame(attr1 = 3:4),
+    generators = list(Generator$new(inputs = "missing_attr", outputs = "attr2"))
+  )
+  expect_error(sim_manager$run(), "The model simulator function has not been set")
+})
+
+test_that("custom results filenames and extensions", {
+  sim_manager <- SimulationManager$new(
+    results_filename_attributes = c("prefix_", "attr1", "_postfix"),
+    results_ext = ".rds"
+  )
+  sim_manager$sample_data <- data.frame(attr1 = 1)
+  expect_equal(sim_manager$get_results_filename(1), "prefix__attr1_1__postfix")
+})
+
+test_that("active bindings for results_ext", {
+  sim_manager <- SimulationManager$new()
+  sim_manager$results_ext <- ".csv"
+  expect_equal(sim_manager$results_ext, ".csv")
+})
